
# pypaq - python tools package (NLP, RL, ML, NN, TF, MP)

-----------------

## pypaq
Package with some python tools.
Tools are mainly related to Machine Learning tasks like Neural Networks, Reinforcement, Optimization, Hyperparameters Search.
Package created by Piotr Niewinski while working on different projects.

## Naming conventions

Naming conventions used in pypaq code:

| pattern      | description |
| ---          | ---         
| general
| n_*          | number of * 
| *L           | list      
| *D           | dict
| *_ix, *_IX   | index
| *_id, *_ID   | id
| *AV          | average
| *F           | factor (usually 0.0-1.0) 
| *P, *_prob   | probability (0.0-1.0)
| paths
| *_dir, *_DIR | directory, folder, relative or absolute
| *_fn, *_FN   | file name (without dir)
| *_fp, *_FP   | full path (dir + file_name), relative or absolute
| TensorFlow
| *_PH         | placeholder
| *_vars       | list of variables
